import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
  axisLeft,
  axisBottom
} from 'd3';

const height = 500;
const width = 960;
const padding = 20;
const centerX = width / 2;
const centerY = height / 2;

const colors = ['red', 'blue', 'green', 'yellow', 'black', 'magenta', 'orange', 'cyan', 'teal', 'brown'];

const csvURL =
  'https://gist.githubusercontent.com/curran/0ac4077c7fc6390f5dd33bf5c06cb5ff/raw/605c54080c7a93a417a3cea93fd52e7550e76500/UN_Population_2019.csv';

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.Population = parseInt(d['2020']);
      return d;
    };
    csv(csvURL, row).then((data) => {
      setData(data.slice(0, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  // Look at the formatting of the objects in the dataset.
  console.log(data[0]);

  const yScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([padding, height - padding]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([padding, width - padding]);
  
  return (
    <svg width={width} height={height}>
      {data.map((d) => (
        <rect
          x={0}
          y={yScale(d.Country)}
          width={xScale(d.Population)}
          height={yScale.bandwidth()}
          fill={colors[Math.round(Math.random() * 9)]}
        />
      ))}
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
